#! /usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chalk = require("chalk");
var program = require("commander");
var fs_1 = require("fs");
var build_task_1 = require("./tasks/build.task");
var options = JSON.parse(fs_1.readFileSync('./ng-static-site-generator.json').toString());
registerCommand('build', 'Builds the static site.', build)
    .option('--prod', 'Production build.');
registerCommand('watch', 'Builds the static site and rebuilds after changes.', watch);
program.parse(process.argv);
if (process.argv.slice(2).length === 0) {
    program.outputHelp((function (help) { return chalk.red(help); }));
}
else {
    var validCommands_1 = program.commands.map(function (command) { return command.name; });
    var invalidCommands = program.args.filter(function (command) { return typeof command === 'string' && validCommands_1.indexOf(command) === -1; });
    if (invalidCommands.length > 0) {
        console.log(chalk.red("[ERROR] - Invalid command: " + invalidCommands.join(', ')));
        program.outputHelp((function (help) { return chalk.red(help); }));
    }
}
function build(flags) {
    var buildMode = flags.prod ? build_task_1.BuildMode.ProductionBuild : build_task_1.BuildMode.Build;
    return new build_task_1.BuildTask(buildMode, options);
}
function watch() {
    return new build_task_1.BuildTask(build_task_1.BuildMode.Watch, options);
}
function registerCommand(command, description, task) {
    return program
        .command(command)
        .description(description)
        .action(function (flags) { return task(flags).run().catch(function () { process.exit(1); }); });
}
//# sourceMappingURL=cli.js.map