"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var fs_1 = require("fs");
var js_yaml_1 = require("js-yaml");
var path_1 = require("path");
var ArrayObservable_1 = require("rxjs/observable/ArrayObservable");
var html_minify_1 = require("../utilities/html-minify");
var markdown_1 = require("../utilities/markdown");
var injection_tokens_1 = require("./../module/injection-tokens");
var transform_html_1 = require("./transform-html");
var RendererBlogService = (function () {
    function RendererBlogService(production, moduleOptions, generatorOptions) {
        this.production = production;
        this.moduleOptions = moduleOptions;
        this.generatorOptions = generatorOptions;
    }
    RendererBlogService.prototype.getBlogList = function () {
        return ArrayObservable_1.ArrayObservable.of(this.getBlogListSync());
    };
    RendererBlogService.prototype.getBlogEntry = function (date, urlSlug) {
        var filename = date + "-" + urlSlug;
        return ArrayObservable_1.ArrayObservable.of(this.getBlogEntryByFilename(filename));
    };
    RendererBlogService.prototype.getBlogListSync = function (setBody) {
        var _this = this;
        if (setBody === void 0) { setBody = false; }
        return fs_1.readdirSync(this.generatorOptions.blogPath)
            .map(function (filename) { return _this.getBlogEntryByFilename(filename, setBody); })
            .sort(function (entryA, entryB) { return entryB.date.localeCompare(entryA.date); });
    };
    RendererBlogService.prototype.getBlogEntryByFilename = function (blogFilename, setBody) {
        if (setBody === void 0) { setBody = true; }
        var filenames = [blogFilename + ".md", blogFilename + ".html"];
        var matchingFilenames = fs_1.readdirSync(this.generatorOptions.blogPath)
            .filter(function (filename) { return filename === blogFilename || filenames.indexOf(filename) >= 0; });
        if (matchingFilenames.length === 1) {
            var filename = matchingFilenames[0];
            var fileContents = fs_1.readFileSync(path_1.join(this.generatorOptions.blogPath, filename)).toString();
            return this.parseBlogFileContents(filename, fileContents, setBody);
        }
    };
    RendererBlogService.prototype.parseBlogFilename = function (filename) {
        var filenameMatch = /^([0-9]{4}-[0-9]{2}-[0-9]{2})-(.+)\.(md|html)$/g.exec(filename);
        var date = filenameMatch[1];
        var urlSlug = filenameMatch[2];
        return { date: date, urlSlug: urlSlug };
    };
    RendererBlogService.prototype.parseBlogFileContents = function (filename, fileContents, setBody) {
        var parsedFilename = this.parseBlogFilename(filename);
        var fileContentsMatch = /^---(?:\r|\n)((?:.|\r|\n)+?)(?:\r|\n)---(?:\r|\n)((?:.|\r|\n)+)$/g.exec(fileContents);
        var date = parsedFilename.date;
        var url = "/blog/" + date + "/" + parsedFilename.urlSlug;
        var metadata = js_yaml_1.safeLoad(fileContentsMatch[1].trim());
        var body = setBody ? this.processBody(filename, fileContentsMatch[2].trim()) : undefined;
        return __assign({ date: date, url: url, body: body }, metadata);
    };
    RendererBlogService.prototype.processBody = function (filename, rawBody) {
        var html = filename.endsWith('.html') ? rawBody : markdown_1.renderMarkdownToHtml(rawBody);
        if (this.moduleOptions.openExternalLinksInNewTab) {
            html = transform_html_1.transformHtml(html, [transform_html_1.makeExternalLinksTargetBlank]);
        }
        return this.production ? html_minify_1.minifyHtml(html) : html;
    };
    return RendererBlogService;
}());
RendererBlogService = __decorate([
    core_1.Injectable(),
    __param(0, core_1.Inject(injection_tokens_1.PRODUCTION)),
    __param(1, core_1.Inject(injection_tokens_1.MODULE_OPTIONS)),
    __param(2, core_1.Inject(injection_tokens_1.GENERATOR_OPTIONS)),
    __metadata("design:paramtypes", [Boolean, Object, Object])
], RendererBlogService);
exports.RendererBlogService = RendererBlogService;
//# sourceMappingURL=renderer-blog.service.js.map