"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var parse5_1 = require("parse5");
function transformHtml(html, visitors) {
    if (html) {
        var document_1 = parse5_1.parse(html);
        visitNode(document_1, visitors);
        return parse5_1.serialize(document_1);
    }
}
exports.transformHtml = transformHtml;
function removeInnerHtmlAttributes(node) {
    if (node.attrs) {
        var element = node;
        var innerHtmlAttributeIndex = element.attrs.findIndex(function (attr) { return attr.name === 'innerhtml'; });
        if (innerHtmlAttributeIndex > -1) {
            element.attrs.splice(innerHtmlAttributeIndex, 1);
        }
    }
}
exports.removeInnerHtmlAttributes = removeInnerHtmlAttributes;
function makeExternalLinksTargetBlank(node) {
    if (node.tagName === 'a') {
        var linkElement = node;
        var targetAttr = linkElement.attrs.find(function (attr) { return attr.name === 'target'; });
        var hrefAttr = linkElement.attrs.find(function (attr) { return attr.name === 'href'; });
        var href = hrefAttr ? hrefAttr.value : undefined;
        if (targetAttr === undefined && href && href.startsWith('http')) {
            linkElement.attrs.push({ name: 'target', value: '_blank' });
        }
    }
}
exports.makeExternalLinksTargetBlank = makeExternalLinksTargetBlank;
function visitNode(node, visitors) {
    for (var _i = 0, visitors_1 = visitors; _i < visitors_1.length; _i++) {
        var visitor = visitors_1[_i];
        visitor(node);
    }
    if (node.childNodes) {
        for (var _a = 0, _b = node.childNodes; _a < _b.length; _a++) {
            var childNode = _b[_a];
            visitNode(childNode, visitors);
        }
    }
}
//# sourceMappingURL=transform-html.js.map