"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var del = require("del");
var webpack = require("webpack");
var generate_webpack_config_1 = require("./../webpack/generate-webpack-config");
var WebpackStats = require('webpack/lib/Stats');
var BuildMode;
(function (BuildMode) {
    BuildMode[BuildMode["Build"] = 0] = "Build";
    BuildMode[BuildMode["Watch"] = 1] = "Watch";
    BuildMode[BuildMode["ProductionBuild"] = 2] = "ProductionBuild";
})(BuildMode = exports.BuildMode || (exports.BuildMode = {}));
var BuildTask = (function () {
    function BuildTask(mode, options) {
        this.options = options;
        this.watch = mode === BuildMode.Watch;
        this.production = mode === BuildMode.ProductionBuild;
    }
    BuildTask.prototype.run = function () {
        var _this = this;
        return this.runWebpackBuild()
            .then(function () { return _this.deleteUnnecessaryArtifacts(); });
    };
    BuildTask.prototype.runWebpackBuild = function () {
        var _this = this;
        var webpackConfig = generate_webpack_config_1.generateWebpackConfig(this.options, this.watch, this.production);
        var webpackCompiler = webpack(webpackConfig);
        return new Promise(function (resolve, reject) {
            if (_this.watch) {
                webpackCompiler.watch({ poll: false }, function (error, stats) { _this.webpackCompilerCallback(error, stats, resolve, reject); });
            }
            else {
                webpackCompiler.run(function (error, stats) { _this.webpackCompilerCallback(error, stats, resolve, reject); });
            }
        });
    };
    BuildTask.prototype.webpackCompilerCallback = function (error, multiStats, resolve, reject) {
        if (error || multiStats.hasErrors()) {
            if (multiStats) {
                this.printStats(multiStats, true);
            }
            if (error) {
                console.log(error.toString());
            }
            reject();
        }
        else {
            this.printStats(multiStats);
            resolve();
        }
    };
    BuildTask.prototype.printStats = function (multiStats, error) {
        if (error === void 0) { error = false; }
        var results;
        if (error) {
            results = multiStats.stats
                .map(function (stats) { return stats.toString({ colors: true }); })
                .join('\n\n');
        }
        else {
            var excludePattern_1 = this.production ? /temp|styles.*\.js/ : /temp/;
            var assets = multiStats.stats
                .map(function (stats) { return stats.toJson({ assets: true }).assets; })
                .reduce(function (prev, curr) { return prev.concat(curr); }, [])
                .filter(function (asset) { return asset.name.match(excludePattern_1) === null; });
            results = assets.length ? WebpackStats.jsonToString({ assets: assets }, true) : undefined;
        }
        if (results) {
            console.log(results);
        }
    };
    BuildTask.prototype.deleteUnnecessaryArtifacts = function () {
        if (this.watch === false) {
            var filesToDelete = [
                '*temp*'
            ].concat((this.production ? ['styles*.js'] : []));
            return del(filesToDelete, { cwd: this.options.distPath })
                .then(function () { return void 0; });
        }
    };
    return BuildTask;
}());
exports.BuildTask = BuildTask;
//# sourceMappingURL=build.task.js.map