"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var webpack = require("webpack");
var webpackNodeExternals = require('webpack-node-externals');
var VirtualModuleWebpackPlugin = require('virtual-module-webpack-plugin');
var asset_names_1 = require("./asset-names");
var generate_client_app_webpack_config_1 = require("./generate-client-app-webpack-config");
var get_loaders_1 = require("./get-loaders");
var ng_static_site_generator_plugin_1 = require("./ng-static-site-generator-plugin");
function generateStaticSiteWebpackConfig(options, watch, production, buildTemplate) {
    var loaderOptions = {
        production: production,
        client: false,
        emitFiles: buildTemplate,
        includeHash: watch === false
    };
    var stylesEntry = buildTemplate ? { 'styles': options.stylesPath } : {};
    return {
        target: 'node',
        externals: [
            webpackNodeExternals()
        ],
        entry: __assign((_a = {}, _a[asset_names_1.blogHashName] = asset_names_1.blogHashPath, _a[asset_names_1.generatorScriptName] = asset_names_1.generatorScriptPath, _a), stylesEntry),
        output: {
            path: path_1.resolve(options.distPath),
            filename: '[name].js'
        },
        resolve: {
            extensions: ['.js', '.ts']
        },
        module: {
            rules: get_loaders_1.getLoaders(loaderOptions)
        },
        plugins: [
            new VirtualModuleWebpackPlugin({
                moduleName: asset_names_1.blogHashPath,
                contents: options.blogPath
            }),
            new VirtualModuleWebpackPlugin({
                moduleName: asset_names_1.generatorScriptPath,
                contents: generateEntryScript(options, production)
            })
        ].concat((production ? [new webpack.NoEmitOnErrorsPlugin()] : []), (buildTemplate ? generate_client_app_webpack_config_1.getTemplatePlugins(options, watch, production, ['styles']) : []), [
            new ng_static_site_generator_plugin_1.NgStaticSiteGeneratorPlugin(options)
        ])
    };
    var _a;
}
exports.generateStaticSiteWebpackConfig = generateStaticSiteWebpackConfig;
function generateEntryScript(options, production) {
    var appModule = parseModulePath(options.appModule);
    var appComponent = parseModulePath(options.appComponent);
    var appRoutes = parseModulePath(options.appRoutes);
    return "import 'reflect-metadata';\nimport 'zone.js/dist/zone-node';\n\nimport { generateStaticSite } from 'ng-static-site-generator/dist/lib/generate-static-site';\n\nimport { " + appModule.name + " } from '" + appModule.path + "';\nimport { " + appComponent.name + " } from '" + appComponent.path + "';\nimport { " + appRoutes.name + " } from '" + appRoutes.path + "';\n\ngenerateStaticSite(" + appModule.name + ", " + appComponent.name + ", " + appRoutes.name + ", " + JSON.stringify(options) + ", " + production + ");";
}
function parseModulePath(modulePath) {
    var parts = modulePath.split('#');
    return { path: parts[0], name: parts[1] };
}
//# sourceMappingURL=generate-static-site-webpack-config.js.map