"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chalk = require("chalk");
var child_process_1 = require("child_process");
var crypto_1 = require("crypto");
var path_1 = require("path");
var fs_utilities_1 = require("./../utilities/fs.utilities");
var asset_names_1 = require("./asset-names");
var NgStaticSiteGeneratorPlugin = (function () {
    function NgStaticSiteGeneratorPlugin(options) {
        this.options = options;
    }
    NgStaticSiteGeneratorPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.plugin('emit', function (compilation, callback) {
            var blogHashAsset = compilation.assets[asset_names_1.blogHashAssetName];
            NgStaticSiteGeneratorPlugin.blogHash = blogHashAsset ? blogHashAsset.source() : NgStaticSiteGeneratorPlugin.blogHash;
            var scriptAsset = compilation.assets[asset_names_1.generatorScriptAssetName];
            NgStaticSiteGeneratorPlugin.script = scriptAsset ? scriptAsset.source() : NgStaticSiteGeneratorPlugin.script;
            var templateAsset = compilation.assets[asset_names_1.templateAssetName];
            NgStaticSiteGeneratorPlugin.template = templateAsset ? templateAsset.source() : NgStaticSiteGeneratorPlugin.template;
            var currentHash = _this.computeHash(NgStaticSiteGeneratorPlugin.blogHash + NgStaticSiteGeneratorPlugin.script + NgStaticSiteGeneratorPlugin.template);
            if (NgStaticSiteGeneratorPlugin.targetCompiler === undefined && templateAsset !== undefined) {
                NgStaticSiteGeneratorPlugin.targetCompiler = compiler;
            }
            var shouldGenerate = NgStaticSiteGeneratorPlugin.blogHash !== undefined
                && NgStaticSiteGeneratorPlugin.script !== undefined
                && NgStaticSiteGeneratorPlugin.template !== undefined
                && NgStaticSiteGeneratorPlugin.lastHash !== currentHash
                && NgStaticSiteGeneratorPlugin.targetCompiler === compiler;
            if (shouldGenerate) {
                console.log("\n\n" + chalk.gray('ng-static-site-generator running...') + "\n");
                NgStaticSiteGeneratorPlugin.lastHash = currentHash;
                _this.executeGeneratorScript(compilation)
                    .then(function () { callback(); })
                    .catch(function (error) { callback(error); });
            }
            else {
                callback();
            }
        });
    };
    NgStaticSiteGeneratorPlugin.prototype.executeGeneratorScript = function (compilation) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var scriptPath = path_1.join(_this.options.distPath, asset_names_1.generatorScriptAssetName);
            fs_utilities_1.safeWriteFileSync(scriptPath, NgStaticSiteGeneratorPlugin.script);
            var scriptProcess = child_process_1.fork(scriptPath);
            scriptProcess.send({ template: NgStaticSiteGeneratorPlugin.template });
            scriptProcess.on('message', function (message) {
                if (message.source === 'ng-static-site-generator') {
                    if (message.error) {
                        reject(new Error("ng-static-site-generator encountered an error: " + message.error));
                    }
                    else if (message.files) {
                        _this.addRenderedFiles(compilation, message.files);
                    }
                }
            });
            scriptProcess.on('exit', function (code) {
                if (code && code > 0) {
                    reject(new Error('ng-static-site-generator exited with an error.'));
                }
                else {
                    resolve();
                }
            });
        });
    };
    NgStaticSiteGeneratorPlugin.prototype.addRenderedFiles = function (compilation, files) {
        var _loop_1 = function (file) {
            compilation.assets[file.path] = {
                source: function () { return file.contents; },
                size: function () { return file.contents.length; }
            };
        };
        for (var _i = 0, _a = files.sort(function (fileA, fileB) { return fileA.path.localeCompare(fileB.path); }); _i < _a.length; _i++) {
            var file = _a[_i];
            _loop_1(file);
        }
    };
    NgStaticSiteGeneratorPlugin.prototype.computeHash = function (value) {
        var sha1 = crypto_1.createHash('sha1');
        return sha1.update(value).digest('hex').substr(0, 20);
    };
    return NgStaticSiteGeneratorPlugin;
}());
exports.NgStaticSiteGeneratorPlugin = NgStaticSiteGeneratorPlugin;
//# sourceMappingURL=ng-static-site-generator-plugin.js.map